pysophia documentation — pysophia 0.1 documentation

### Navigation

- index
- modules |
- pysophia 0.1 documentation »

# pysophia documentation

This package provides C bindings for sophia, a ligthweight DBM-like database. Available operations on a database are inserting a key-value pair, deleting it, or retrieving a value given its key. It is also possible to traverse the records of a database in ascending or descending order.

## Installation

With pip:

    pip install sophia

With the source package:

    python setup.py install

If you want to check how the library performs, look at the benchmarks on the website of the author, and run the script `bench.py` located in the `tests` directory of this package.

## Contents

- Tutorial
  - Basics
  - Storing and deleting records
  - Retrieving records
  - Traversing records
  - Storing rich objects
  - Tuning
  - On threading
  - Cursor pitfall
  - Final notes
- Reference
  - Main objects
  - Database models

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- pysophia 0.1 documentation »